@@ -38,5 +38,4 @@ def subset(client):
     client.run()
 
 
-split_subset = launchable.CommonSplitSubsetImpls(
-    __name__, seperator=',').split_subset()
+split_subset = launchable.CommonSplitSubsetImpls(__name__, seperator=',').split_subset()
